@@ -44,12 +44,14 @@
 #include <KComponentData>
 
 #include <QApplication>
-#include <QtCore/QArgument>
-#include <QtCore/QObject>
-#include <QtCore/QByteRef>
-#include <QtCore/QEvent>
-#include <QtCore/QFile>
+#include <QArgument>
+#include <QObject>
+#include <QByteRef>
+#include <QEvent>
+#include <QFile>
 #include <QDropEvent>
+#include <QDBusConnection>
+#include <QMimeData>
 #ifdef KActivities_FOUND
 #endif
 
@@ -63,7 +65,6 @@
 #include <KParts/OpenUrlArguments>
 #include <KParts/BrowserExtension>
 #include <KParts/WindowArgs>
-#include <KComponentData>
 
 //#define DEBUG_HISTORY
 
